
# Slot: boolean_slot


A grouping of slots that expression a boolean operator over a list of operands

URI: [linkml:boolean_slot](https://w3id.org/linkml/boolean_slot)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Expression](Expression.md)

## Parents


## Children

 *  [all_of](all_of.md)
 *  [any_of](any_of.md)
 *  [exactly_one_of](exactly_one_of.md)
 *  [none_of](none_of.md)

## Used by

